@@ -413,8 +413,12 @@ gaussian.CARadaptive <- function(formula, data = NULL, W, burnin, n.sample, thin
   }
   
   # end timer
-  if(verbose) cat("\nSummarising results."); close(progressBar)  
-  
+  if(verbose)
+  {
+  cat("\nSummarising results.")
+  close(progressBar)
+  }else
+  {}
   
 ###################################
 #### Summarise and save the results 
@@ -508,7 +512,7 @@ samples.beta.orig <- common.betatransform(samples.beta, X.indicator, X.mean, X.s
   
 #### Compile and return the results
 model.string    <- c("Likelihood model - Gaussian (identity link function)", 
-                       "\nLatent structure model - Adaptive autoregressive CAR model\n")
+                       "\nLatent structure model - Adaptive autoregressive order 1 CAR model\n")
   samples.tau2all <- cbind(samples.tau2, samples.vtau2)
   colnames(samples.tau2all) <- c("tau2", "tau2.w")
   if(is.null(rhofix))
