@@ -689,8 +689,7 @@ poisson.CARclustrends <- function(formula, data=NULL, W, burnin, n.sample, thin=
     #-------------------------------------------------------------------------------------------------------------------------------------------------------
     # Self tune the acceptance probabilties
     #-------------------------------------------------------------------------------------------------------------------------------------------------------
-    k <- j/100
-    if(ceiling(k)==floor(k))
+    if(ceiling(j/100)==floor(j/100) & j < burnin)
     {
       #-------------------------------------------------------------------------------------------------------------------------------------------------------
       # Determine the acceptance probabilities
